@@ -62,7 +62,7 @@ return [
 			'url' => '/api/{apiVersion}/signaling/settings',
 			'verb' => 'GET',
 			'requirements' => [
-				'apiVersion' => 'v(1|2)',
+				'apiVersion' => 'v(3)',
 			],
 		],
 		[
@@ -70,7 +70,7 @@ return [
 			'url' => '/api/{apiVersion}/signaling/welcome/{serverId}',
 			'verb' => 'GET',
 			'requirements' => [
-				'apiVersion' => 'v(1|2)',
+				'apiVersion' => 'v(3)',
 				'serverId' => '^\d+$',
 			],
 		],
@@ -79,7 +79,7 @@ return [
 			'url' => '/api/{apiVersion}/signaling/backend',
 			'verb' => 'POST',
 			'requirements' => [
-				'apiVersion' => 'v(1|2)',
+				'apiVersion' => 'v(3)',
 			],
 		],
 		[
@@ -87,7 +87,7 @@ return [
 			'url' => '/api/{apiVersion}/signaling/{token}',
 			'verb' => 'POST',
 			'requirements' => [
-				'apiVersion' => 'v(1|2)',
+				'apiVersion' => 'v(3)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -96,7 +96,7 @@ return [
 			'url' => '/api/{apiVersion}/signaling/{token}',
 			'verb' => 'GET',
 			'requirements' => [
-				'apiVersion' => 'v(1|2)',
+				'apiVersion' => 'v(3)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -109,7 +109,7 @@ return [
 			'url' => '/api/{apiVersion}/call/{token}',
 			'verb' => 'GET',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -118,7 +118,16 @@ return [
 			'url' => '/api/{apiVersion}/call/{token}',
 			'verb' => 'POST',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
+				'token' => '^[a-z0-9]{4,30}$',
+			],
+		],
+		[
+			'name' => 'Call#updateCallFlags',
+			'url' => '/api/{apiVersion}/call/{token}',
+			'verb' => 'PUT',
+			'requirements' => [
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -127,7 +136,7 @@ return [
 			'url' => '/api/{apiVersion}/call/{token}',
 			'verb' => 'DELETE',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -199,7 +208,7 @@ return [
 			'url' => '/api/{apiVersion}/room',
 			'verb' => 'GET',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 			],
 		],
 		[
@@ -207,7 +216,7 @@ return [
 			'url' => '/api/{apiVersion}/listed-room',
 			'verb' => 'GET',
 			'requirements' => [
-				'apiVersion' => 'v3',
+				'apiVersion' => 'v(4)',
 			],
 		],
 		[
@@ -215,7 +224,7 @@ return [
 			'url' => '/api/{apiVersion}/room',
 			'verb' => 'POST',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 			],
 		],
 		[
@@ -223,7 +232,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}',
 			'verb' => 'GET',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -232,7 +241,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}',
 			'verb' => 'PUT',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -241,7 +250,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}',
 			'verb' => 'DELETE',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -250,7 +259,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/public',
 			'verb' => 'POST',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -259,7 +268,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/public',
 			'verb' => 'DELETE',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -268,7 +277,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/description',
 			'verb' => 'PUT',
 			'requirements' => [
-				'apiVersion' => 'v3',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -277,7 +286,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/read-only',
 			'verb' => 'PUT',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -286,7 +295,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/listable',
 			'verb' => 'PUT',
 			'requirements' => [
-				'apiVersion' => 'v3',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -295,7 +304,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/password',
 			'verb' => 'PUT',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -304,7 +313,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/participants',
 			'verb' => 'GET',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -313,16 +322,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/participants',
 			'verb' => 'POST',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
-				'token' => '^[a-z0-9]{4,30}$',
-			],
-		],
-		[
-			'name' => 'Room#removeParticipantFromRoom',
-			'url' => '/api/{apiVersion}/room/{token}/participants',
-			'verb' => 'DELETE',
-			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -331,16 +331,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/participants/self',
 			'verb' => 'DELETE',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
-				'token' => '^[a-z0-9]{4,30}$',
-			],
-		],
-		[
-			'name' => 'Room#removeGuestFromRoom',
-			'url' => '/api/{apiVersion}/room/{token}/participants/guests',
-			'verb' => 'DELETE',
-			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -349,7 +340,16 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/attendees',
 			'verb' => 'DELETE',
 			'requirements' => [
-				'apiVersion' => 'v3',
+				'apiVersion' => 'v(4)',
+				'token' => '^[a-z0-9]{4,30}$',
+			],
+		],
+		[
+			'name' => 'Room#setAttendeePublishingPermissions',
+			'url' => '/api/{apiVersion}/room/{token}/attendees/publishing-permissions',
+			'verb' => 'PUT',
+			'requirements' => [
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -358,7 +358,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/participants/active',
 			'verb' => 'POST',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -367,7 +367,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/participants/resend-invitations',
 			'verb' => 'POST',
 			'requirements' => [
-				'apiVersion' => 'v3',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -376,7 +376,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/participants/active',
 			'verb' => 'DELETE',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -385,7 +385,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/moderators',
 			'verb' => 'POST',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -394,7 +394,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/moderators',
 			'verb' => 'DELETE',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -403,7 +403,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/favorite',
 			'verb' => 'POST',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -412,7 +412,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/favorite',
 			'verb' => 'DELETE',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
@@ -421,7 +421,7 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/pin/{pin}',
 			'verb' => 'GET',
 			'requirements' => [
-				'apiVersion' => 'v3',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 				'pin' => '^\d{7,32}$',
 			],
@@ -431,27 +431,25 @@ return [
 			'url' => '/api/{apiVersion}/room/{token}/notify',
 			'verb' => 'POST',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
 		[
 			'name' => 'Room#setLobby',
-			'url' => '/api/{apiVersion}/room/{token}/{webinar}/lobby',
+			'url' => '/api/{apiVersion}/room/{token}/webinar/lobby',
 			'verb' => 'PUT',
 			'requirements' => [
-				'apiVersion' => 'v(1|2|3)',
-				'webinar' => 'webinary?',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
 		[
 			'name' => 'Room#setSIPEnabled',
-			'url' => '/api/{apiVersion}/room/{token}/{webinar}/sip',
+			'url' => '/api/{apiVersion}/room/{token}/webinar/sip',
 			'verb' => 'PUT',
 			'requirements' => [
-				'apiVersion' => 'v3',
-				'webinar' => 'webinary?',
+				'apiVersion' => 'v(4)',
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
