@@ -94,6 +94,7 @@ OC.L10N.register(
     "{actor} shared a file which is no longer available" : "Restr rannet {actor} n'eo ket posupl kavout kenn",
     "You shared a file which is no longer available" : "Ar restr o peus rannet n'eo ket posupl kavout kenn",
     "%s (guest)" : "%s (kouviat)",
+    "You missed a call from {user}" : "C'hwitet o peus ur gemenadenn eus {user}",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})"],
     "Call with {user1} and {user2} (Duration {duration})" : "Kemenadenn gant {user1} ha {user2} (Padelez {duration})",
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Kemenadenn gant {user1}, {user2} ha {user3} (Padelez {duration})",
@@ -138,7 +139,6 @@ OC.L10N.register(
     "{user} invited you to a group conversation: {call}" : "{user} e deus kouviet ac'hnoc'h d'ur strolat diviz : {call}",
     "Answer call" : "Respont d'ar gemenadenn",
     "Call back" : "adober ur gemenadenn",
-    "You missed a call from {user}" : "C'hwitet o peus ur gemenadenn eus {user}",
     "A group call has started in {call}" : "Ur gemenadenn strollat a zo kroget e {call}",
     "You missed a group call in {call}" : "C'hwitet ho peus ur gemenadenn strollat e {call}",
     "{email} is requesting the password to access {file}" : "{email} a goulenn ar ger-tremen evit tizout {restr}",
@@ -641,6 +641,7 @@ OC.L10N.register(
     "No camera available" : "Kamera ebet kavet",
     "Select camera" : "Choaz ur c'hamera",
     "Reply" : "Respont",
+    "Go to file" : "Mont d'ar restr",
     "[Unknown username]" : "[Anv implijer dianv]",
     "Today" : "Hiziv",
     "Yesterday" : "Dec'h",
@@ -683,7 +684,6 @@ OC.L10N.register(
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Adnevesaet e bet Nextcloud Talk, ret eo deoc'h freskaat ar bajenn a raok kregiñ pe mont en ut gamanadenn.",
     "You will be able to join the call only after a moderator starts it." : "Posupl vo deoc'h mont er gemenadenn goude ma vo bet groget gant ar modertator.",
     "Toggle fullscreen" : "Lakat/Kuitaat ar skramm a bezh",
-    "Go to file" : "Mont d'ar restr",
     "Rename conversation" : "Adenvel an diviz",
     "Mute others" : "Lakaat ar re all mut",
     "Grid view" : "Diskwell ar roued",
@@ -747,7 +747,7 @@ OC.L10N.register(
     "New in Talk 9" : "Nevez e Talk 9",
     "{user} wants to talk with you" : "{user} en dus c'hoant da gomz deoc'h",
     "Users that can not use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Implijourien na c'hellont ket impij Talk ken a vo laosket e rollioù en divizoù lec'h m'ho deus kemeret perzh ho gwarnet a vo ho gemenadennoù.",
-    "Signaling server URL" : "O arhentañ URL ar servijour",
+    "E-mail of the user" : "Postel an implijer",
     "Error: Can not connect to server" : "Fazi : N'eo ket posupl kenstaga ar servijour",
     "UDP and TCP" : "UDP ha TCP",
     "UDP only" : "UDP nemetken",
@@ -761,21 +761,15 @@ OC.L10N.register(
     "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Lakaat ar video en dro (v) -Ho genstagadenn a vo troc'het evit aotreañ ar video evit ar wech kentañ",
     "This conversation is read only" : "An diviz a zo da lenn-nemetken",
     "Conversation, " : "Diviz,",
-    "Default location for attachments" : "Lec'h dre ziouer evit ar stagadennoù",
-    "Select default location for attachments" : "Choaz al lec'h stagadenn dre ziouer",
     "Allow guests to join via link " : "Aotreaén ar c'houvidi da don dre liamm",
+    "Remove" : "Lemel",
+    "Enabled" : "Aotreet",
     "Participant settings" : "Arventennoù tud",
     "Add participants to the conversation" : "Ouzhpennañ tud en diviz",
-    "Projects" : "Raktres",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call" : "Nextcloud Talk a zo bet adnevesaet, ret eo deoc'h freskaat ar bajenn a raok kregin pe mont en ur gemenadenn",
     "Share link" : "Rannan liamm",
     "Exit fullscreen (f)" : "Kuitaat ar skramm a bez (f)",
     "Fullscreen (f)" : "Skramm a bez (f)",
-    "Select a conversation to add to the project" : "Choaz un diviz da ouzhpennañ er raktres",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "N'eo ket douget pen-da-benn ho furcher gant Nextcloud Talk. Implijit kentec'h stum divezhañ Mozilla Firefox, Microsoft Edge, Google Chrome pe Apple Safari.",
-    "Error while uploading file" : "Ur fazi a zo bet en ur pellkas ar restr",
-    "E-mail of the user" : "Postel an implijer",
-    "Remove" : "Lemel",
-    "Enabled" : "Aotreet"
+    "Error while uploading file" : "Ur fazi a zo bet en ur pellkas ar restr"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
