@@ -75,6 +75,7 @@ OC.L10N.register(
     "{actor} shared a file which is no longer available" : "{actor} delte en fil, der ikke længere er tilgængelig",
     "You shared a file which is no longer available" : "Du delte en fil, der ikke længere er tilgængelig",
     "%s (guest)" : "%s (gæst)",
+    "You missed a call from {user}" : "Du missede et opkald fra {user}",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Opkald med 1 gæst (Varighed {duration})","Opkald med %n gæster (Varighed {duration})"],
     "Call with {user1} and {user2} (Duration {duration})" : "Opkald med {user1} og {user2} (Varighed {duration})",
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Opkald med {user1}, {user2} og {user3} (Varighed {duration})",
@@ -113,7 +114,6 @@ OC.L10N.register(
     "{user} invited you to a group conversation: {call}" : "{user} inviterede dig til en gruppesamtale: {call}",
     "Answer call" : "Besvar opkald",
     "Call back" : "Ring tilbage",
-    "You missed a call from {user}" : "Du missede et opkald fra {user}",
     "A group call has started in {call}" : "Et gruppeopkald er startet i {call}",
     "You missed a group call in {call}" : "Du missede en gruppesamtale i {call}",
     "{email} is requesting the password to access {file}" : "{email} anmoder om adgangskoden til {file}",
@@ -284,8 +284,6 @@ OC.L10N.register(
     "Share this link to invite others!" : "Del dette link for at invitere andre!",
     "Conversation link copied to clipboard." : "Samtalelink kopieret til udklipsholder",
     "The link could not be copied." : "Linket kunne ikke kopieres.",
-    "Share whole screen" : "Del hele skærmen",
-    "Share a single window" : "Del et vindue",
     "Show your screen" : "Vis din skærm",
     "Stop screensharing" : "Stop skærmdeling",
     "Settings" : "Indstillinger",
@@ -358,7 +356,7 @@ OC.L10N.register(
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Du venter nu i lobbyen. Dette møde er planlagt til {startTime}",
     "Camera" : "Kamera",
     "Reply" : "Besvar",
-    "Remove" : "Fjern",
+    "Go to file" : "Gå til fil",
     "[Unknown username]" : "[Ukendt brugernavn]",
     "Today" : "I dag",
     "Yesterday" : "I går",
@@ -390,7 +388,6 @@ OC.L10N.register(
     "Search" : "Søg",
     "Error while setting attachment folder" : "Fejl under indstilling af mappe til vedhæftninger",
     "Start call" : "Start opkald",
-    "Go to file" : "Gå til fil",
     "Rename conversation" : "Omdøb samtale",
     "Grid view" : "Grid visning",
     "Send" : "Send",
@@ -432,26 +429,24 @@ OC.L10N.register(
     "New in Talk 8" : "Nyt i Talk 8",
     "{user} wants to talk with you" : "{user} vil gerne snakke med dig",
     "Users that can not use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Brugere som ikke længere kan bruge Talk vil stadig fremgå som deltagere i tidligere samtaler de har deltaget i, og deres chat-beskeder vil blive gemt.",
-    "Signaling server URL" : "Signalserver URL",
     "UDP and TCP" : "UDP og TCP",
     "UDP only" : "kun UDP",
     "TCP only" : "kun TCP",
+    "Share whole screen" : "Del hele skærmen",
+    "Share a single window" : "Del et vindue",
     "Mute audio (m)" : "Slå lyden fra (m)",
     "Unmute audio (m)" : "Slå lyden til (m)",
     "Disable video (v)" : "Slå video fra (v)",
     "Enable video (v)" : "Slå video til (v)",
     "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Aktiver video (v) - Forbindelsen forsvinder et øjeblik første gang du slår video til",
     "This conversation is read only" : "Denne samtale er skrivebeskyttet",
-    "Default location for attachments" : "Standard-lokation for vedhæftninger",
-    "Select default location for attachments" : "Vælg standard-lokation for vedhæftninger",
     "Allow guests to join via link " : "Tillad gæster at deltage via link",
+    "Remove" : "Fjern",
+    "Enabled" : "Aktiveret",
     "Add participants to the conversation" : "Tilføj deltagere til samtalen",
-    "Projects" : "Projekter",
     "Share link" : "Del link",
     "Exit fullscreen (f)" : "Forlad fuldskærmsvisning (f)",
     "Fullscreen (f)" : "Vis i fuldskærm (f)",
-    "Select a conversation to add to the project" : "Vælg en samtale for at tilføje den til projektet",
-    "Error while uploading file" : "Fejl ved upload af fil",
-    "Enabled" : "Aktiveret"
+    "Error while uploading file" : "Fejl ved upload af fil"
 },
 "nplurals=2; plural=(n != 1);");
