@@ -35,9 +35,6 @@ OC.L10N.register(
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} pervadino pokalbį iš \"%1$s\" į \"%2$s\"",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Jūs pervadinote pokalbį iš \"%1$s\" į \"%2$s\"",
     "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Administratorius pervadino pokalbį iš \"%1$s\" į \"%2$s\"",
-    "{actor} set the description to \"%1$s\"" : "{actor} nustatė aprašą į „%1$s“",
-    "You set the description to \"%1$s\"" : "Jūs nustatėte aprašą į „%1$s“",
-    "An administrator set the description to \"%1$s\"" : "Administratorius nustatė aprašą į „%1$s“",
     "{actor} removed the description" : "{actor} pašalino aprašą",
     "You removed the description" : "Jūs pašalinote aprašą",
     "An administrator removed the description" : "Administratorius pašalino aprašą",
@@ -92,17 +89,8 @@ OC.L10N.register(
     "An administrator demoted {user} from moderator" : "Administratorius pažemino naudotoją {user} iš moderatorių",
     "{actor} shared a file which is no longer available" : "{actor} pradėjo bendrinti failą, kuris daugiau nebeprieinamas",
     "You shared a file which is no longer available" : "Jūs pradėjote bendrinti failą, kuris daugiau nebeprieinamas",
-    "{actor} set up Matterbridge to synchronize this conversation with other chats." : "{actor} nustatė „Matterbridge“, kad sinchronizuotų šį pokalbį su kitais pokalbiais.",
-    "You set up Matterbridge to synchronize this conversation with other chats." : "Jūs nustatėte „Matterbridge“, kad sinchronizuotumėte šį pokalbį su kitais pokalbiais.",
-    "{actor} updated the Matterbridge configuration." : "{actor} atnaujino „Matterbridge“ konfigūraciją.",
-    "You updated the Matterbridge configuration." : "Jūs atnaujinote „Matterbridge“ konfigūraciją.",
-    "{actor} removed the Matterbridge configuration." : "{actor} pašalino „Matterbridge“ konfigūraciją.",
-    "You removed the Matterbridge configuration." : "Jūs pašalinote „Matterbridge“ konfigūraciją.",
-    "{actor} started Matterbridge." : "{actor} paleido „Matterbridge“.",
-    "You started Matterbridge." : "Jūs paleidote „Matterbridge“.",
-    "{actor} stopped Matterbridge." : "{actor} sustabdė „Matterbridge“.",
-    "You stopped Matterbridge." : "Jūs sustabdėte „Matterbridge“.",
     "%s (guest)" : "%s (svečias)",
+    "You missed a call from {user}" : "Jūs praleidote skambutį nuo {user}",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Skambutis su %n svečiu (Trukmė {duration})","Skambutis su %n svečiais (Trukmė {duration})","Skambutis su %n svečių (Trukmė {duration})","Skambutis %n svečiu (Trukmė {duration})"],
     "Call with {user1} and {user2} (Duration {duration})" : "Skambutis su {user1} ir {user2} (Trukmė {duration})",
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Skambutis su {user1}, {user2} ir {user3} (Trukmė {duration})",
@@ -111,6 +99,11 @@ OC.L10N.register(
     "Talk to %s" : "Kalbėti su %s",
     "File is not shared, or shared but not with the user" : "Failas nėra bendrinamas arba yra bendrinamas, tačiau ne su naudotoju",
     "No account available to delete." : "Nėra ištrynimui prieinamos paskyros.",
+    "File is too big" : "Failas yra per didelis",
+    "Invalid file provided" : "Pateiktas neteisingas failas",
+    "Invalid image" : "Netinkamas paveikslas",
+    "Unknown filetype" : "Nežinomas failo tipas",
+    "An error occurred. Please contact your admin." : "Įvyko klaida. Susisiekite su savo administratoriumi.",
     "Talk mentions" : "Paminėjimai pokalbiuose",
     "Write to conversation" : "Rašyti į pokalbį",
     "Writes event information into a conversation of your choice" : "Parašo apie įvykio informaciją į jūsų pasirinktą pokalbį",
@@ -146,7 +139,6 @@ OC.L10N.register(
     "Answer call" : "Atsiliepti",
     "{user} would like to talk with you" : "{user} norėtų su jumis pakalbėti",
     "Call back" : "Atskambinti",
-    "You missed a call from {user}" : "Jūs praleidote skambutį nuo {user}",
     "A group call has started in {call}" : "Grupės skambutis prasidėjo ties {call}",
     "You missed a group call in {call}" : "Jūs praleidote grupės skambutį ties {call}",
     "{email} is requesting the password to access {file}" : "{email} prašo slaptažodžio, kad gautų prieigą prie {file}",
@@ -429,8 +421,6 @@ OC.L10N.register(
     "Share this link to invite others!" : "Bendrinkite šią nuorodą, norėdami pakviesti kitus!",
     "Conversation link copied to clipboard." : "Pokalbio nuoroda nukopijuota į iškarpinę.",
     "The link could not be copied." : "Nepavyko nukopijuoti nuorodos.",
-    "Share whole screen" : "Bendrinti visą ekraną",
-    "Share a single window" : "Bendrinti vieną langą",
     "Show your screen" : "Rodyti savo ekraną",
     "Stop screensharing" : "Stabdyti ekrano bendrinimą",
     "Settings" : "Nustatymai",
@@ -534,7 +524,7 @@ OC.L10N.register(
     "No microphone available" : "Nėra prieinamo mikrofono",
     "No camera available" : "Nėra prieinamos kameros",
     "Reply" : "Atsakyti",
-    "Remove" : "Šalinti",
+    "Go to file" : "Pereiti į failą",
     "[Unknown username]" : "[Nežinomas naudotojo vardas]",
     "Today" : "Šiandien",
     "Yesterday" : "Vakar",
@@ -569,7 +559,6 @@ OC.L10N.register(
     "Error while setting attachment folder" : "Klaida nustatant priedų aplanką",
     "Start call" : "Pradėti skambutį",
     "Toggle fullscreen" : "Perjungti visą ekraną",
-    "Go to file" : "Pereiti į failą",
     "Rename conversation" : "Pervadinti pokalbį",
     "Grid view" : "Tinklelio rodinys",
     "Send" : "Siųsti",
@@ -617,31 +606,43 @@ OC.L10N.register(
     "New in Talk 7" : "Kas naujo Pokalbiuose 7",
     "New in Talk 8" : "Nauja Pokalbiuose 8",
     "New in Talk 9" : "Nauja Pokalbiuose 9",
+    "New in Talk 10" : "Nauja Pokalbiuose 10",
+    "{actor} set up Matterbridge to synchronize this conversation with other chats." : "{actor} nustatė „Matterbridge“, kad sinchronizuotų šį pokalbį su kitais pokalbiais.",
+    "You set up Matterbridge to synchronize this conversation with other chats." : "Jūs nustatėte „Matterbridge“, kad sinchronizuotumėte šį pokalbį su kitais pokalbiais.",
+    "{actor} updated the Matterbridge configuration." : "{actor} atnaujino „Matterbridge“ konfigūraciją.",
+    "You updated the Matterbridge configuration." : "Jūs atnaujinote „Matterbridge“ konfigūraciją.",
+    "{actor} removed the Matterbridge configuration." : "{actor} pašalino „Matterbridge“ konfigūraciją.",
+    "You removed the Matterbridge configuration." : "Jūs pašalinote „Matterbridge“ konfigūraciją.",
     "{user} wants to talk with you" : "{user} nori su jumis pakalbėti",
-    "Signaling server URL" : "Signalinio serverio URL",
+    "E-mail of the user" : "Naudotojo el. paštas",
     "Error: Can not connect to server" : "Klaida: Nepavyksta prisijungti prie serverio",
     "UDP and TCP" : "UDP ir TCP",
     "UDP only" : "Tik UDP",
     "TCP only" : "Tik TCP",
+    "Share whole screen" : "Bendrinti visą ekraną",
+    "Share a single window" : "Bendrinti vieną langą",
     "Mute audio (m)" : "Nutildyti garsą (m)",
     "Unmute audio (m)" : "Įjungti garsą (m)",
     "Disable video (v)" : "Išjungti vaizdą (v)",
     "Enable video (v)" : "Įjungti vaizdą (v)",
     "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą (v) - Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
     "This conversation is read only" : "Šis pokalbis yra tik skaitymui",
-    "Default location for attachments" : "Numatytoji priedų vieta",
-    "Select default location for attachments" : "Pasirinkti numatytąją vietą priedams",
     "Allow guests to join via link " : "Leisti svečiams prisijungti per nuorodą",
+    "Remove" : "Šalinti",
+    "Enabled" : "Įjungta",
+    "User name or e-mail address" : "Naudotojo vardas ar el. pašto adresas",
     "Participant settings" : "Dalyvio nustatymai",
     "Add participants to the conversation" : "Pridėti dalyvius į pokalbį",
-    "Projects" : "Projektai",
     "Share link" : "Bendrinimo nuoroda",
     "Exit fullscreen (f)" : "Išeiti iš viso ekrano (f)",
     "Fullscreen (f)" : "Visas ekranas (f)",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Nextcloud Pokalbiai nepalaiko pilnai jūsų naudojamos naršyklės. Naudokite naujausią Mozilla Firefox, Microsoft Edge, Google Chrome ar Apple Safari versiją.",
-    "New in Talk 10" : "Nauja Pokalbiuose 10",
-    "E-mail of the user" : "Naudotojo el. paštas",
-    "Enabled" : "Įjungta",
-    "User name or e-mail address" : "Naudotojo vardas ar el. pašto adresas"
+    "{actor} set the description to \"%1$s\"" : "{actor} nustatė aprašą į „%1$s“",
+    "You set the description to \"%1$s\"" : "Jūs nustatėte aprašą į „%1$s“",
+    "An administrator set the description to \"%1$s\"" : "Administratorius nustatė aprašą į „%1$s“",
+    "{actor} started Matterbridge." : "{actor} paleido „Matterbridge“.",
+    "You started Matterbridge." : "Jūs paleidote „Matterbridge“.",
+    "{actor} stopped Matterbridge." : "{actor} sustabdė „Matterbridge“.",
+    "You stopped Matterbridge." : "Jūs sustabdėte „Matterbridge“."
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
