@@ -100,6 +100,7 @@ OC.L10N.register(
     "{actor} shared a file which is no longer available" : "{actor} сподели датотека која не е достапна повеќе",
     "You shared a file which is no longer available" : "Споделивте датотека која не е достапна повеќе",
     "%s (guest)" : "%s (гостин)",
+    "You missed a call from {user}" : "Имате пропуштен повик од {user}",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Повик со %n гостин (Времетраење {duration})","Повик со %n гости (Времетраење {duration})"],
     "Call with {user1} and {user2} (Duration {duration})" : "Повик со {user1} и {user2} (Времетраење {duration})",
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "повик со {user1}, {user2} и {user3} (Времетраење {duration})",
@@ -149,7 +150,6 @@ OC.L10N.register(
     "Answer call" : "Одговори на повикот",
     "{user} would like to talk with you" : "{user} сака да разговара со вас",
     "Call back" : "Јавете се назад",
-    "You missed a call from {user}" : "Имате пропуштен повик од {user}",
     "A group call has started in {call}" : "Започна групен повик {call}",
     "You missed a group call in {call}" : "Имате пропуштен групен повик во {call}",
     "{email} is requesting the password to access {file}" : "{email} побара лозинка за пристап до {file}",
@@ -627,6 +627,7 @@ OC.L10N.register(
     "No camera available" : "Нема камера",
     "Select camera" : "Избери камера",
     "Reply" : "Одговор",
+    "Go to file" : "Оди до датотеката",
     "[Unknown username]" : "[Непознато корисничко име]",
     "Scroll to bottom" : "Скролај до долу",
     "Today" : "Денес",
@@ -677,7 +678,6 @@ OC.L10N.register(
     "Error while setting attachment folder" : "Грешка при поставување на папка за прилози",
     "Start call" : "Повик",
     "Toggle fullscreen" : "Вклучи на цел екран",
-    "Go to file" : "Оди до датотеката",
     "Rename conversation" : "Преименувај разговор",
     "Mute others" : "Занеми ги останатите",
     "Speaker view" : "Поглед на тој што зборува",
@@ -724,9 +724,16 @@ OC.L10N.register(
     "New in Talk 7" : "Ново во Talk 7",
     "New in Talk 8" : "Ново во Talk 8",
     "New in Talk 9" : "Ново во Talk 9",
+    "New in Talk 10" : "Ново во Talk 10",
+    "{actor} set up Matterbridge to synchronize this conversation with other chats." : "{actor} постави мост за да го синхронизира овој разговор со друг разговор на друга платформа.",
+    "You set up Matterbridge to synchronize this conversation with other chats." : "Поставивте мост за да го синхронизира овој разговор со друг разговор на друга платформа.",
+    "{actor} updated the Matterbridge configuration." : "{actor} ја ажурираше конфигурацијата на мостот.",
+    "You updated the Matterbridge configuration." : "Ја ажуриравте конфигурацијата на мостот.",
+    "{actor} removed the Matterbridge configuration." : "{actor} ја избриша конфигурацијата на мостот.",
+    "You removed the Matterbridge configuration." : "Ја избришавте конфигурацијата на мостот.",
     "{user} wants to talk with you" : "{user} сака да разговара со вас",
     "Users that can not use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Корисниците кој повеќе не користат Talk ќе бидат сеуште учесници во нивните предходни разговори и нивните пораки ќе се чуваат.",
-    "Signaling server URL" : "URL за сервер за сигнализација",
+    "E-mail of the user" : "Е-пошта на корисник",
     "Error: Can not connect to server" : "Грешка: Неможе да се поврзе со сервер",
     "UDP and TCP" : "UDP и TCP",
     "UDP only" : "Само UDP",
@@ -740,30 +747,18 @@ OC.L10N.register(
     "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Овозможи видео (v) - Вашата врска ќе биде кратко прекината при овозможување на видеото за прв пат",
     "This conversation is read only" : "Разговорот е само за читање",
     "Conversation, " : "Разговор,",
-    "Default location for attachments" : "Стандардна локација за прилози",
-    "Select default location for attachments" : "Избери стандардна локација за прилози",
     "Allow guests to join via link " : "Дозволи им на гостите да се приклучат преку линк",
-    "Add participants to the conversation" : "Додадете учесници кон разговорот",
-    "Projects" : "Проекти",
-    "Use speaker view" : "Користете поглед кон тој што зборува",
-    "Share link" : "Сподели линк",
-    "Exit fullscreen (f)" : "Излез од цел екран (f)",
-    "Fullscreen (f)" : "Приказ на цел екран (f)",
-    "Select a conversation to add to the project" : "Избери разговор за да го додадете во проект",
-    "Error while uploading file" : "Грешка при прикачување на датотека",
-    "New in Talk 10" : "Ново во Talk 10",
-    "{actor} set up Matterbridge to synchronize this conversation with other chats." : "{actor} постави мост за да го синхронизира овој разговор со друг разговор на друга платформа.",
-    "You set up Matterbridge to synchronize this conversation with other chats." : "Поставивте мост за да го синхронизира овој разговор со друг разговор на друга платформа.",
-    "{actor} updated the Matterbridge configuration." : "{actor} ја ажурираше конфигурацијата на мостот.",
-    "You updated the Matterbridge configuration." : "Ја ажуриравте конфигурацијата на мостот.",
-    "{actor} removed the Matterbridge configuration." : "{actor} ја избриша конфигурацијата на мостот.",
-    "You removed the Matterbridge configuration." : "Ја избришавте конфигурацијата на мостот.",
-    "E-mail of the user" : "Е-пошта на корисник",
     "Remove" : "Отстрани",
     "Bridge with other services" : "Мост со други сервери",
     "Enabled" : "Овозможен",
     "User name or e-mail address" : "Корисничко име или е-пошта адреса",
+    "Add participants to the conversation" : "Додадете учесници кон разговорот",
     "Choose in which folder attachments should be saved." : "Изберете во која папка ќе се зачувуваат примероците.",
+    "Share link" : "Сподели линк",
+    "Exit fullscreen (f)" : "Излез од цел екран (f)",
+    "Fullscreen (f)" : "Приказ на цел екран (f)",
+    "Error while uploading file" : "Грешка при прикачување на датотека",
+    "Use speaker view" : "Користете поглед кон тој што зборува",
     "{actor} set the description to \"%1$s\"" : "{actor} го постави описот во \"%1$s\"",
     "You set the description to \"%1$s\"" : "Го променивте описот во \"%1$s\"",
     "An administrator set the description to \"%1$s\"" : "Администраторот го постави описот во \"%1$s\""
