@@ -484,8 +484,11 @@ OC.L10N.register(
     "New in Talk 7" : "Nytt i Talk 7",
     "New in Talk 8" : "Nytt i Talk 8",
     "New in Talk 9" : "Nytt i Talk 9",
+    "New in Talk 10" : "Nytt i Talk 10",
+    "You updated the Matterbridge configuration." : "Du oppdaterte Matterbridge innstillingene.",
+    "You removed the Matterbridge configuration." : "Du fjernet Matterbridge innstillingene.",
     "{user} wants to talk with you" : "{user} ønsker å snakke med deg",
-    "Signaling server URL" : "Sender signal til servers URL",
+    "E-mail of the user" : "Brukerens epostadresse",
     "UDP and TCP" : "UDP og TCP",
     "UDP only" : "kun UDP",
     "TCP only" : "kun TCP",
@@ -495,16 +498,11 @@ OC.L10N.register(
     "Unmute audio (m)" : "Slå på lyd (m)",
     "Disable video (v)" : "Skru av video (v)",
     "Enable video (v)" : "Skru på video (v)",
-    "Projects" : "Prosjekter",
+    "Remove" : "Fjern",
+    "Enabled" : "Aktivert",
     "Share link" : "Del lenke",
     "Exit fullscreen (f)" : "Avslutt fullskjermsvisning (f)",
     "Fullscreen (f)" : "Fullskjermsvisning (f)",
-    "New in Talk 10" : "Nytt i Talk 10",
-    "You updated the Matterbridge configuration." : "Du oppdaterte Matterbridge innstillingene.",
-    "You removed the Matterbridge configuration." : "Du fjernet Matterbridge innstillingene.",
-    "E-mail of the user" : "Brukerens epostadresse",
-    "Remove" : "Fjern",
-    "Enabled" : "Aktivert",
     "{actor} set the description to \"%1$s\"" : "{actor} satte beskrivelsen til \"%1$s\"",
     "You set the description to \"%1$s\"" : "Du satte beskrivelsen til \"%1$s\"",
     "An administrator set the description to \"%1$s\"" : "En administrator satte beskrivelsen til \"%1$s\"",
