@@ -29,9 +29,9 @@ OC.L10N.register(
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} a renomenat la conversacion de « %1$s » a « %2$s »",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Avètz renomenat la conversacion de « %1$s » a « %2$s »",
     "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Un administrator a renomenat la conversacion de « %1$s » a « %2$s »",
-    "{actor} set the description to \"%1$s\"" : "{actor} a definit la descripcion « %1$s »",
-    "You set the description to \"%1$s\"" : "Avètz definit la descripcion « %1$s »",
-    "An administrator set the description to \"%1$s\"" : "Un administrator a definit la descripcion « %1$s »",
+    "{actor} set the description" : "{actor} escriguèt la descripcion",
+    "You set the description" : "Avètz escricha la descripcion",
+    "An administrator set the description" : "Un administrator escriguèt la descripcion",
     "{actor} removed the description" : "{actor} a tirat la descripcion",
     "You removed the description" : "Avètz tirat la descripcion",
     "An administrator removed the description" : "Un administrator a tirat la descripcion",
@@ -59,6 +59,8 @@ OC.L10N.register(
     "The conversation is now open to everyone" : "La conversacion es ara dubèrta a tot lo monde",
     "{actor} opened the conversation to everyone" : "{actor} a dubèrta la conversacion a tot lo monde",
     "You opened the conversation to everyone" : "Avètz dobèrta la conversacion a tot lo monde",
+    "{actor} restricted the conversation to moderators" : "{actor} a restrench la conversacion als moderators",
+    "You restricted the conversation to moderators" : "Avètz restrench la conversacion als moderators",
     "{actor} allowed guests" : "{actor} autorizèt los convidats",
     "You allowed guests" : "Avètz autorizat los convidats",
     "An administrator allowed guests" : "Un administrator autorizèt los convidats",
@@ -85,13 +87,25 @@ OC.L10N.register(
     "{actor} removed you" : "{actor} vos a levat",
     "An administrator removed you" : "Un administrator vos a levat",
     "An administrator removed {user}" : "Un administrator a tirat {user}",
-    "You stopped Matterbridge." : "Avètz arrestat Matterbridge.",
+    "{actor} removed group {group}" : "{actor} levèt lo grop {group}",
+    "You removed group {group}" : "Avètz levat lo grop {group}",
+    "An administrator removed group {group}" : "Un administrator tirèt lo grop {group}",
+    "{actor} shared a file which is no longer available" : "{actor} partegèt un fichièr qu’es pas pus disponible",
+    "You shared a file which is no longer available" : "Partegèretz un fichièr qu'es pas pus disponible",
+    "You updated the Matterbridge configuration" : "Avètz actualizada la configuracion Matterbridge",
+    "{actor} removed the Matterbridge configuration" : "{actor} suprimissèt la configuracion Matterbridge",
+    "You removed the Matterbridge configuration" : "Avètz suprimida la configuracion Matterbdrige",
+    "{actor} started Matterbridge" : "{actor} a lançat Matterbridge",
+    "You started Matterbridge" : "Avètz lançat Matterbridge",
+    "{actor} stopped Matterbridge" : "{actor} arrestèt Matterbridge",
+    "You stopped Matterbridge" : "Avètz arrestat Matterbridge",
     "{actor} deleted a message" : "{actor} a suprimit un messatge",
     "You deleted a message" : "Avètz suprimit un messatge",
     "Message deleted by author" : "Messatge suprimit per son autor",
     "Message deleted by {actor}" : "Messatge suprimit per {actor}",
     "Message deleted by you" : "Messatge suprimit per vos",
     "%s (guest)" : "%s (convidat)",
+    "You missed a call from {user}" : "Avètz mancat una sonada de {user}",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Sonada amb %n convidat (Durada {duration})","Sonada amb %n convidats (Durada {duration})"],
     "Call with {user1} and {user2} (Duration {duration})" : "Sonada amb {user1} e {user2} (Durada {duration})",
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Sonada amb {user1}, {user2} e {user3} (Durada {duration})",
@@ -113,6 +127,7 @@ OC.L10N.register(
     "Conversation invitation" : "Convit de conversacion",
     "Click the button below to join." : "Clicatz sul boton per participar.",
     "Join »%s«" : "Rejónher « %s »",
+    "Dial-in information" : "Entresenhas de sonada",
     "Meeting ID" : "Identificant reünion",
     "Your PIN" : "Vòstre còdi",
     "Password request: %s" : "Senhal requerit : %s",
@@ -124,13 +139,19 @@ OC.L10N.register(
     "Guest in {call}" : "Convidat dins {call}",
     "{user} sent you a private message" : "{user} vos a enviat un messatge privat",
     "{user} sent a message in conversation {call}" : "{user} a enviat un messatge dins la conversacion {call}",
+    "A deleted user sent a message in conversation {call}" : "Un utilizaire suprimit vos envièt un messatge dins la conversacion {call}",
+    "{user} replied to your private message" : "{user} a respondut a vòstre messatge privat",
+    "{user} replied to your message in conversation {call}" : "{user} a respondut a vòstre messatge dins la conversacion {call}",
+    "A deleted user replied to your message in conversation {call}" : "Un utilizaire suprimit a respondut a vòstre messatge dins la conversacion {call}",
+    "A deleted user mentioned you in conversation {call}" : "Un utilizaire suprimit vos a mencionat dins la conversacion {call}",
     "A guest mentioned you in conversation {call}" : "Un convidat vos a mencionat dins la conversacion {call}",
     "View chat" : "Veire lo chat",
     "Join call" : "Rejónher la sonada",
     "Answer call" : "Respondre a l’apèl",
     "{user} would like to talk with you" : "{user} volriá vos parlar",
     "Call back" : "Tornar",
-    "You missed a call from {user}" : "Avètz mancat una sonada de {user}",
+    "You missed a group call in {call}" : "Avètz mancat una sonada de grop dins {call}",
+    "Someone is requesting the password to access {file}" : "Qualqu’un demanda lo senhal per accedir a {file}",
     "Open settings" : "Dobrir los paramètres",
     "Conversations" : "Discussions",
     "Messages" : "Messatges",
@@ -139,7 +160,7 @@ OC.L10N.register(
     "{user} in {conversation}" : "{user} dins {conversation}",
     "Messages in other conversations" : "Messatges dins autras conversacions",
     "Something unexpected happened." : "Quicòm d’inesperat s’es produch.",
-    "The URL is invalid." : "L’URL es invalida",
+    "The URL is invalid." : "L’URL es invalida.",
     "An HTTPS URL is required." : "Una URL HTTPS es requerida.",
     "The email address is invalid." : "L’adreça email es invalida.",
     "The language is invalid." : "La lenga es invalida.",
@@ -354,6 +375,7 @@ OC.L10N.register(
     "South Sudan" : "Sodan del Sud",
     "Sao Tome and Principe" : "São Tomé e Príncipe",
     "El Salvador" : "El Salvador",
+    "Sint Maarten (Dutch part)" : "Sant Martin (part neerlandesa)",
     "Syrian Arab Republic" : "Siria",
     "Turks and Caicos Islands" : "Illas Turcas e Caïcas",
     "Chad" : "Chad",
@@ -369,6 +391,7 @@ OC.L10N.register(
     "Turkey" : "Turquia",
     "Trinidad and Tobago" : "Trinitat e Tobago",
     "Tuvalu" : "Tuvalu",
+    "Taiwan, Province of China" : "Taiwan, Província de China",
     "Tanzania, United Republic of" : "Tanzania",
     "Ukraine" : "Ucraïna",
     "Uganda" : "Oganda",
@@ -376,7 +399,9 @@ OC.L10N.register(
     "United States of America" : "Estats Units d'America",
     "Uruguay" : "Uruguai",
     "Uzbekistan" : "Ozbequistan",
+    "Holy See" : "Santa Ses",
     "Saint Vincent and the Grenadines" : "Sant Vincenç e las Grenadinas",
+    "Venezuela, Bolivarian Republic of" : "República Bolivariana de Venezuela",
     "Virgin Islands, British" : "Illas Verges Britanicas",
     "Virgin Islands, U.S." : "Virgin Islands, U.S.",
     "Viet Nam" : "Vinyes",
@@ -440,6 +465,7 @@ OC.L10N.register(
     "Active" : "Activa",
     "Expired" : "Expirat",
     "_%n user_::_%n users_" : ["%n utilizaire","%n utilizaires"],
+    "Matterbridge integration" : "Integracion Matterbridge",
     "Downloading …" : "Telecargament…",
     "Install Talk Matterbridge" : "Installar Talk Matterbridge",
     "Installed version: {version}" : "Version installada : {version}",
@@ -453,10 +479,13 @@ OC.L10N.register(
     "Status: Checking connection" : "Estat : verificacion de la connexion",
     "OK: Running version: {version}" : "OK : execucion de la version : {version}",
     "Error: Cannot connect to server" : "Error : connexion impossibla al servidor",
+    "Error: Server did not respond with proper JSON" : "Error: lo servidor a pas respondut amb un JSON corrèct",
+    "Error: Server responded with: {error}" : "Error : lo servidor a respondut : {error}",
     "Error: Unknown error occurred" : "Error : una error desconeguda s'es produsida",
     "Saved" : "Enregistrat",
     "Add a new server" : "Apondre un servidor novèl",
     "It is highly recommended to set up a distributed cache when using Nextcloud Talk together with a High Performance Back-end." : "Es forçadament recomandat de configurar a cache distribuit pendent l’utilizacion de Nextcloud Talk amb un back-end de fòrt rendiment.",
+    "Don't warn about connectivity issues in calls with more than 4 participants" : "Avertir pas dels problèmas de connectivitat dins las sonadas de mai de 4 participants",
     "STUN server URL" : "URL servidor STUN",
     "STUN servers" : "Servidors STUN",
     "TURN server schemes" : "Esquèmas servidor TURN",
@@ -465,8 +494,11 @@ OC.L10N.register(
     "TURN server URL" : "URL servidor TURN",
     "TURN server secret" : "Secrèt servidor TURN",
     "TURN server protocols" : "Protocòls servidor TURN",
+    "{schema} scheme must be used with a domain" : "l’esquèma {schema} deu èsser utilizat amb un domeni",
     "Test this server" : "Ensajar aqueste servidor",
     "TURN servers" : "Servidor TURN",
+    "{nickName} raised their hand." : "{nickName} a levat la man.",
+    "A participant raised their hand." : "Un participant a levat la man.",
     "Previous page of videos" : "Pagina de vidèos precedenta",
     "Next page of videos" : "Pagina de vidèos seguenta",
     "Copy link" : "Copiar lo ligam",
@@ -474,8 +506,7 @@ OC.L10N.register(
     "Waiting for others to join the call …" : "En espèra que d’autres arriben…",
     "Share this link to invite others!" : "Partejatz aqueste ligam per convidar mai de monde !",
     "Conversation link copied to clipboard." : "Ligam de conversacion copiat al quichapapièrs.",
-    "Share whole screen" : "Partejar l’ecran complet",
-    "Share a single window" : "Partejar sonque una fenèstra",
+    "The link could not be copied." : "Impossible de copiar lo ligam.",
     "Show your screen" : "Partejar l’ecran",
     "Stop screensharing" : "Arrestar partiment d’ecran",
     "Lower hand (R)" : "Baissar la man (R)",
@@ -483,16 +514,20 @@ OC.L10N.register(
     "Settings" : "Paramètres",
     "Dismiss" : "Regetar",
     "Raise hand (R)" : "Levar la man (R)",
+    "You are not allowed to enable audio" : "Avètz pas l'autorizacion per activar l’àudio",
     "No audio" : "Cap d’àudio",
     "Mute audio (M)" : "Copar lo son (M)",
     "Unmute audio (M)" : "Restablir lo son (M)",
     "Mute audio" : "Copar lo son",
     "Unmute audio" : "Restablir lo son",
+    "You are not allowed to enable video" : "Avètz pas l'autorizacion per activar la vidèo",
     "No camera" : "Cap de camèra",
     "Disable video (V)" : "Desactivar la vidèo (V)",
     "Enable video (V)" : "Activar la vidèo (V)",
     "Disable video" : "Desactivar la vidèo",
     "Enable video" : "Activar la vidèo",
+    "You are not allowed to enable screensharing" : "Avètz pas l'autorizacion per activar lo partiment d’ecran",
+    "No screensharing" : "Cap de partiment d’ecran",
     "Screensharing options" : "Opcion de partiment d’ecran",
     "Enable screensharing" : "Activar lo partiment d’ecran",
     "Bad sent video and screen quality." : "Marrida vidèo enviada e qualitat d’ecran.",
@@ -505,6 +540,7 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "S’es producha una error en aviant lo partiment d’ecran.",
     "Back" : "Retorn",
     "Access to camera was denied" : "L’accès a la camèra es estat refusat",
+    "Error while accessing camera: it is likely in use by another program" : "Error d’accès a la camèra : poiriá arribar qu’un autre programa l’utiliza",
     "Error while accessing camera" : "Error pendent l’accès a la camèra",
     "You have been muted by a moderator" : "Un moderator vos a amudit",
     "You" : "Vos",
@@ -519,11 +555,14 @@ OC.L10N.register(
     "Call in progress" : "Sonada en cors",
     "Favorite" : "Favorit",
     "Conversation settings" : "Paramètres de conversacion",
+    "Description" : "Descripcion",
+    "Enter a description for this conversation" : "Picatz una descripcion per aquesta conversacion",
     "Chat notifications" : "Notificacions de chat",
     "Guests access" : "Accès convidat",
     "Meeting settings" : "Paramètres de reünion",
     "Matterbridge" : "Matterbridge",
     "Danger zone" : "Zòna perilhosa",
+    "Error while updating conversation description" : "Error pendent l’actualizacion de la descripcion de la conversacion",
     "Be careful, these actions cannot be undone." : "Fasètz atencion, aquelas accions pòdon pas èsser anulladas.",
     "Leave conversation" : "Quitar la conversacion",
     "Delete conversation" : "Suprimir la conversacion",
@@ -538,12 +577,29 @@ OC.L10N.register(
     "Resend invitations" : "Tornar enviar las invitacions",
     "Conversation password has been saved" : "Lo senhal de conversacion es estat enregistrat",
     "Conversation password has been removed" : "Lo senhal de conversacion es estat suprimit",
+    "Error occurred while saving conversation password" : "Error pendent l'enregistrament del senhal de la conversacion",
+    "Error occurred while allowing guests" : "Error en autorizant los convidats",
+    "Error occurred while disallowing guests" : "Error en autorizant pas mai los convidats",
     "Invitations sent" : "Invitacions enviadas",
+    "Error occurred when sending invitations" : "Error en enviant las invitacions",
+    "Open conversation to registered users" : "Dobrir la conversacion als utilizaires enregistrats",
+    "This conversation will be shown in search results" : "Aquesta conversacion serà mostrada als resultats de recèrca",
+    "Error occurred when opening or limiting the conversation" : "Error en dobrissent o limitant la conversacion",
+    "Enabling the lobby only allows moderators to post messages." : "Activar la sala d’espèra permet als moderators de publicar de messatges.",
+    "This will also remove non-moderators from the ongoing call." : "Aquò tirarà tanben los non moderators de la sonada en cors.",
     "Enable lobby" : "Activar la sala d’espèra",
     "After the time limit the lobby will be automatically disabled." : "Aprèp la limita de temps la sala d’espèra serà automaticament desactivada.",
     "Meeting start time" : "Ora de debuta de la conferéncia",
     "Start time (optional)" : "Ora de debuta (opcional)",
+    "Error occurred when restricting the conversation to moderator" : "Error pendent la restriccion de la conversacion al moderator",
+    "Error occurred when opening the conversation to everyone" : "Error pendent la dubertura de la conversacion a tot lo monde",
+    "Start time has been updated" : "L'ora de debuta es estada actualizada",
+    "Error occurred while updating start time" : "Error pendent la mesa a jorn de l’ora de debuta",
+    "Locking the conversation prevents anyone to post messages or start calls." : "Lo verrolhatge de la conversacion empacha qual que siá de publicar de messatges o començar de sonadas.",
+    "This will also terminate the ongoing call." : "Aquò acabarà tanben la sonada en cors.",
     "Lock conversation" : "Verrolhar la conversacion",
+    "Error occurred when locking the conversation" : "Error pendent lo verrolhatge de la conversacion",
+    "Error occurred when unlocking the conversation" : "Error pendent lo desverrolhatge de la conversacion",
     "Save" : "Salvar",
     "Edit" : "Modificar",
     "More information" : "Mai d’informacions",
@@ -558,12 +614,19 @@ OC.L10N.register(
     "Mattermost user" : "Utilizaire Mattermost",
     "Team name" : "Nom de la còla",
     "Channel name" : "Nom de la cadena",
+    "User name or email address" : "Nom d’utilizaire o adreça email",
     "Password" : "Senhal",
+    "Skip TLS verification" : "Passar la verificacion TLS",
+    "Zulip server URL" : "URL servidor Zulip",
     "Bot user name" : "Nom d’utilizaire robòt",
     "Bot API key" : "Clau d’API robòt",
+    "Zulip channel" : "Canal Zulip",
     "API token" : "Geton API",
+    "Server ID or name" : "ID o nom del servidor",
+    "Channel ID or name" : "ID o nom del canal",
     "Channel" : "Cadena",
     "Login" : "Login",
+    "Chat ID" : "ID del chat",
     "Nickname" : "Escais",
     "Connection password" : "Senhal de connexion",
     "IRC channel" : "Cadena IRC",
@@ -572,7 +635,6 @@ OC.L10N.register(
     "NickServ password" : "Senhal NickServ",
     "Use TLS" : "Utilizar TLS",
     "Use SASL" : "Utilizar SASL",
-    "Skip TLS verification" : "Passar la verificacion TLS",
     "Tenant ID" : "ID Tenant",
     "Client ID" : "ID client",
     "Team ID" : "ID Team",
@@ -583,8 +645,9 @@ OC.L10N.register(
     "unknown state" : "estat desconegut",
     "running" : "en cors d'execucion",
     "not running" : "pas en execucion",
-    "Conversation \"{conversationName}\"" : "Conversacion « {conversationName} »",
-    "Settings for conversation \"{conversationName}\"" : "Paramètres per la conversacion « {conversationName} »",
+    "Cancel editing description" : "Anullar la modificacion de la descripcion",
+    "Submit conversation description" : "Enviar la descripcion de la conversacion",
+    "Edit conversation description" : "Editar la descripcion de la conversacion",
     "Mark as read" : "Marcar coma legit",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
@@ -601,7 +664,11 @@ OC.L10N.register(
     "Talk settings" : "Paramètres Talk",
     "Users and groups" : "Utilizaires e grops",
     "Other sources" : "Autras fonts",
+    "An error occurred while performing the search" : "Una error s'es producha en realizant la recèrca",
     "Creating your conversation" : "Creacion de vòstra conversacion",
+    "All set" : "Tot es prèst",
+    "Error while creating the conversation" : "Error pendent la creacion de la conversacion",
+    "Link copied to the clipboard!" : "Ligam copiat al quichapapièrs !",
     "Create a new group conversation" : "Crear una conversacion de grop novèla",
     "Password protect" : "Protegir per un senhal",
     "Add participants" : "Apondre participants",
@@ -611,7 +678,10 @@ OC.L10N.register(
     "Search participants" : "Cercar participants",
     "Conversation name" : "Nom de conversacion",
     "Allow guests to join via link" : "Permetre als convidats de rejónher via ligam",
+    "Search conversations or users" : "Cercar de conversacions o utilizaires",
     "You are currently waiting in the lobby" : "Sètz a esperar dins la sala d’espèra",
+    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Sètz a esperar dins la sala d’espèra. Aquesta conferéncia es planificada per {startTime}",
+    "Calls are not supported in your browser" : "Vòstre navegador pren pas encarga las sonadas",
     "Access to microphone is only possible with HTTPS" : "L’accès al microfòn es sonque possibla amb HTTPS",
     "Access to microphone was denied" : "L’accès al microfòn es estat refusat",
     "Error while accessing microphone" : "Error pendent l’accès al microfòn",
@@ -623,31 +693,52 @@ OC.L10N.register(
     "No camera available" : "Cap de camèra pas disponibla",
     "Select camera" : "Causir una camèra",
     "Reply" : "Respondre",
+    "Reply privately" : "Respondre en privat",
     "Copy message link" : "Copiar ligam messatge",
     "Mark as unread" : "Marcar coma pas legit",
+    "Go to file" : "Anar al fichièr",
     "Unread messages" : "Messatges pas legits",
     "Sending message" : "Mandadís del messatge",
     "Message sent" : "Messatge mandat",
     "Not enough free space to upload file" : "Pas pro d’espaci liure per enviar lo fichièr",
+    "You are not allowed to share files" : "Avètz pas lo drech de partejar de fichièrs",
+    "You cannot send messages to this conversation at the moment" : "Podètz pas enviar de messatges a aquesta conversacion pel moment",
     "Deleting message" : "Supression del messatge",
     "Message deleted successfully" : "Messatge corrèctament suprimit",
+    "Message could not be deleted because it is too old" : "Lo messatge a pas pogut èsser suprimit perque es tròp ancian",
+    "Only normal chat messages can be deleted" : "Sonque los messatges de chat normal pòdon èsser suprimits",
+    "An error occurred while deleting the message" : "Error pendent la supression del messatge",
+    "Message link copied to clipboard." : "Ligam del messatge copiat al quichapapièrs.",
+    "Your browser does not support playing audio files" : "Vòstre navegador pren pas en carga la lectura dels fichièrs àudio",
+    "Contact" : "Contacte",
     "{stack} in {board}" : "{stack} dins {board}",
-    "Remove" : "Suprimir",
+    "Remove {fileName}" : "Suprimir {fileName}",
+    "Open this location in Openstreetmap" : "Dobrir aqueste lòc dins Openstreetmap",
     "[Unknown username]" : "[utilizaire desconegut]",
+    "Scroll to bottom" : "Desfilar enbàs",
     "Today" : "Uèi",
     "Yesterday" : "Ièr",
+    "Record voice message" : "Enregistrar messatge vocal",
+    "End recording and send" : "Acabar àudio e enviar",
+    "Dismiss recording" : "Anullar l’enregistrament",
+    "Access to the microphone was denied" : "L’accès al microfòn es estat refusat",
+    "Error while recording audio" : "Error en enregistrant l’àudio",
+    "Talk recording from {time} ({conversation})" : "Enregistrament Talk a partir de {time} ({conversation})",
+    "Share files to the conversation" : "Partejar de fichièrs dins la conversacion",
     "Upload new files" : "Enviar fichièrs novèls",
+    "Share from Files" : "Partejar a partir dels Fichièrs",
     "Add emoji" : "Apondre emoji",
     "Send message" : "Enviar un messatge",
     "File to share" : "Fichièr de partejar",
     "This conversation has been locked" : "Aquesta conversacion foguèt clavada",
     "Write message, @ to mention someone …" : "Escriure un messatge, @ per mencionar qualqu’un…",
-    "Cancel editing description" : "Anullar la modificacion de la descripcion",
-    "Description" : "Descripcion",
+    "Invalid path selected" : "Camin seleccionat invalid",
     "Disable lobby" : "Desactivar la sala d’espèra",
     "moderator" : "moderator",
     "bot" : "robòt",
     "guest" : "convidat",
+    "Resend invitation" : "Renviar invitacion",
+    "Remove group and members" : "Levar de grops e membres",
     "Remove participant" : "Tirar participant",
     "Settings for participant \"{user}\"" : "Paramètres pel participant « {user} »",
     "Add participant \"{user}\"" : "Apondre participant « {user} »",
@@ -656,20 +747,21 @@ OC.L10N.register(
     "Joined with video" : "Rejonhèt amb vidèo",
     "Joined via phone" : "Rejonhèt via telefòn",
     "Raised their hand" : "Levèt la man",
+    "Invitation was sent to {actorId}." : "Invitacion enviada a {actorId}.",
+    "Could not send invitation to {actorId}" : "Mandadís impossible del convit a {actorId}",
     "Add users" : "Apondre utilizaires",
     "Add groups" : "Apondre grops",
     "Add emails" : "Apondre emails",
     "Searching …" : "Recèrca…",
     "No results" : "Pas cap de resultat",
     "Add users or groups" : "Add users or groups",
+    "Add other sources" : "Apondre d'autras fonts",
     "Participants" : "Participants",
     "Search or add participants" : "Cercar o apondre participants",
     "An error occurred while adding the participants" : "Una error s’es producha en ajustant los participants",
     "An error occurred while fetching the participants" : "Una error s’es producha en recuperant los participants",
-    "Add a description for this conversation" : "Apondre una descripcion per aquesta conversacion",
     "Chat" : "Messatjariá",
     "Details" : "Detalhs",
-    "Error while updating conversation description" : "Error pendent l’actualizacion de la descripcion de la conversacion",
     "Meeting ID: {meetingId}" : "ID reünion : {meetingId}",
     "Your PIN: {attendeePin}" : "Vòstre PIN : {attendeePin}",
     "Display name: " : "Nom d’afichatge :",
@@ -677,7 +769,7 @@ OC.L10N.register(
     "Attachments folder" : "Dossièr de pèças-juntas",
     "Privacy" : "Confidencialitat",
     "Sounds" : "Sons",
-    "Play sounds when participants join a call or leave it" : "Emetre sons quand los participants rejonhon o quitan una sonada",
+    "Play sounds when participants join or leave a call" : "Emetre sons quand los participants rejonhon o quitan una sonada",
     "Keyboard shortcuts" : "Acorchis de clavièr",
     "Speed up your Talk experience with these quick shortcuts." : "Acceleratz vòstra experiéncia Talk amb aqueles acorchis.",
     "Fullscreen the chat or call" : "Passar la messatjariá o la sonada en plen ecran",
@@ -687,19 +779,27 @@ OC.L10N.register(
     "Microphone on and off" : "Microfòn activat/desactivat",
     "Space bar" : "barra d’espaci",
     "Push to talk or push to mute" : "Tocar per parlar o tocar per copar lo son",
+    "Raise or lower hand" : "Levar o baissar la man",
+    "Choose the folder in which attachments should be saved." : "Causir lo dossièr ont seràn gardadas las pèça juntas.",
     "Select location for attachments" : "Causir un emplaçament per las pèças juntas",
+    "Error while setting attachment folder" : "Error pendent la definicion del dossièr de pèça junta",
+    "Your privacy setting has been saved" : "Paramètre de confidencialitat enregistrat",
+    "Error while setting read status privacy" : "Error lor de definicion de la confidencialitat de l'estatut",
     "Failed to save sounds setting" : "Cargament impossible del paramètre de son",
     "Sounds setting saved" : "Paramètres de son enregistrats",
+    "Error while saving sounds setting" : "Error en enregistrant lo paramètre de son",
     "Start call" : "Començar sonada",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk foguèt mes a jorn, vos cal recargar la pagina abans de poder començar o participar a una sonada.",
+    "You will be able to join the call only after a moderator starts it." : "Poiretz sonque participar a la sonada un còp qu'un moderator l'aja començada.",
     "Conversation actions" : "Accions de conversacion",
     "Toggle fullscreen" : "Bascular en mòde ecran complet",
-    "Go to file" : "Anar al fichièr",
     "Rename conversation" : "Renomenar la conversacion",
     "Mute others" : "Copar lo son dels autres",
     "Exit fullscreen (F)" : "Quitar plen ecran (F)",
     "Fullscreen (F)" : "Plen ecran (F)",
     "Grid view" : "Vista en grasilha",
+    "You have new unread messages in the chat." : "Avètz un messatge pas legit al chat.",
+    "You have been mentioned in the chat." : "Qualqu’un vos a mencionat al chat.",
     "Send" : "Mandar",
     "Add more files" : "Apondre mai de fichièrs",
     "No unread mentions" : "Cap de mencion pas legida",
@@ -715,6 +815,7 @@ OC.L10N.register(
     "Link to a conversation" : "Ligam cap a la conversacion",
     "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Avètz rejonch la conversacion dins una autra fenèstra o periferic. Aquò es actualament pas pres en cargar per Nextcloud Talk doncas aquesta session es estada tampada.",
     "Post to a conversation" : "Publicar dins una conversacion",
+    "Post to conversation" : "Publicar a la conversacion",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Lo navegador qu’utilizatz es pas complètament pres en cargar per Nextcloud Talk. Mercés d’utilizar la darrièra version de Mozilla Firefox, Microsoft Edge, Google Chrome o Apple Safari.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk foguèt mes a jorn, mercés de tornar cargar la pagina",
     "Do not disturb" : "Me desrengar pas",
@@ -722,8 +823,12 @@ OC.L10N.register(
     "Error while sharing file" : "Error pendent lo partiment del fichièr",
     "Not enough free space to upload file \"{fileName}\"" : "Pas pro d’espaci liure per enviar lo fichièr « {fileName} »",
     "Error while uploading file \"{fileName}\"" : "Error en enviant lo fichièr « {fileName} »",
+    "An error happened when trying to share your file" : "Una error s’es producha en ensajant de partejar vòstre fichièr",
     "Leave this page" : "Quitar aquesta pagina",
     "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud es en mòde manteniment, volgatz recargar la pagina",
+    "Sending signaling message has failed." : "Lo mandadís de messatge de senhalament a pas reüssit.",
+    "Lost connection to signaling server. Trying to reconnect." : "Connexion perduda al servidor de senhalament. Ensag de reconnexion.",
+    "Lost connection to signaling server. Try to reload the page manually." : "Connexion perduda al servidor de senhalament. Ensajatz de recargar la pagina manualament.",
     "Default" : "Defaut",
     "Microphone {number}" : "Microfòn {number}",
     "Camera {number}" : "Camèra {number}",
@@ -737,7 +842,9 @@ OC.L10N.register(
     "Error while accessing microphone & camera" : "Error pendent l’accès al microfòn e a la camèra",
     "This conversation is password-protected" : "Aquesta conversacion es protegida per senhal",
     "The password is wrong. Try again." : "Lo senhal es incorrècte. Ensajatz tornamai.",
+    "Specify commands the users can use in chats" : "Indicar las comandas que los utilizaires pòdon utilizar als chats",
     "TURN server" : "Servidor TURN",
+    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Lo servidor TURN es utilizat per desviar lo trafic dels participants darrièr un parafuòc.",
     "Signaling servers" : "Servidors de senhalizacion",
     "%s Talk on your mobile devices" : "%sTalk on vòstres aparelhs mobiles",
     "Android app" : "Aplicacion Android",
@@ -746,40 +853,43 @@ OC.L10N.register(
     "New in Talk 7" : "Nòu dins Talk 7",
     "New in Talk 8" : "Nòu dins Talk 8",
     "New in Talk 9" : "Nòu dins Talk 9",
+    "New in Talk 10" : "Nòu dins Talk 10",
     "{user} wants to talk with you" : "{user} vòl vos parlar",
-    "Signaling server URL" : "URL del servidor de senhalizacion",
+    "E-mail of the user" : "E-mail de l’utilizaire",
     "Error: Can not connect to server" : "Error : connexion impossibla al servidor",
     "UDP and TCP" : "UDP e TCP",
     "UDP only" : "Sonque UDP",
     "TCP only" : "Sonque TCP",
+    "Share whole screen" : "Partejar l’ecran complet",
+    "Share a single window" : "Partejar sonque una fenèstra",
     "Mute audio (m)" : "Copar lo son (m)",
     "Unmute audio (m)" : "Restablir lo son (m)",
     "Disable video (v)" : "Desactivar la vidèo (v)",
     "Enable video (v)" : "Activar la vidèo (v)",
     "This conversation is read only" : "La conversacion es en lectura sola",
     "Conversation, " : "Conversacion, ",
-    "Default location for attachments" : "Emplaçament per defaut per las pèças juntas",
-    "Select default location for attachments" : "Causir un emplaçament per defaut per las pèças juntas",
     "Allow guests to join via link " : "Permetre als convidats de rejónher via ligam",
+    "Remove" : "Suprimir",
+    "More info on Matterbridge." : "Mai d‘informacions sus Matterbridge.",
+    "Enabled" : "Activada",
+    "User name or e-mail address" : "Nom d’utilizaire o adreça electronica",
     "Participant settings" : "Paramètres participants",
     "Add participants to the conversation" : "Apondre participants a la conversacion",
-    "Projects" : "Projèctes",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call" : "Nextcloud Talk foguèt mes a jorn, vos cal recargar la pagina abans de poder començar o participar a una sonada",
+    "Choose in which folder attachments should be saved." : "Causir dins quin dossièr las pèças juntas devon èsser enregistradas.",
     "Share link" : "Partejar lo ligam",
     "Exit fullscreen (f)" : "Sortir del ecran complèt (f)",
     "Fullscreen (f)" : "Ecran complèt (f)",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Lo navegador qu’utilizatz es pas complètament pres en cargar per Nextcloud Talk. Mercés d’utilizar la darrièra version de Mozilla Firefox, Microsoft Edge, Google Chrome o Apple Safari.",
     "Error while uploading file" : "Error en enviant lo fichièr",
-    "New in Talk 10" : "Nòu dins Talk 10",
-    "E-mail of the user" : "E-mail de l’utilizaire",
-    "More info on Matterbridge." : "Mai d‘informacions sus Matterbridge.",
-    "Enabled" : "Activada",
-    "User name or e-mail address" : "Nom d’utilizaire o adreça electronica",
+    "{actor} set the description to \"%1$s\"" : "{actor} a definit la descripcion « %1$s »",
+    "You set the description to \"%1$s\"" : "Avètz definit la descripcion « %1$s »",
+    "An administrator set the description to \"%1$s\"" : "Un administrator a definit la descripcion « %1$s »",
+    "You stopped Matterbridge." : "Avètz arrestat Matterbridge.",
     "Lower hand" : "Baissar la man",
     "Raise hand" : "Levar la man",
+    "Conversation \"{conversationName}\"" : "Conversacion « {conversationName} »",
+    "Settings for conversation \"{conversationName}\"" : "Paramètres per la conversacion « {conversationName} »",
     "You can not send messages to this conversation at the moment" : "Podètz pas enviar de messatges a aquesta conversacion pel moment",
-    "turn: and turns:" : "turn: e turns:",
-    "turn: only" : "turn: sonque",
-    "turns: only" : "turns: sonque"
+    "Add a description for this conversation" : "Apondètz una descripcion per aquesta conversacion"
 },
 "nplurals=2; plural=(n > 1);");
