@@ -291,8 +291,8 @@ OC.L10N.register(
     "The password is wrong. Try again." : "Parola este incorectă. Încercaţi din nou.",
     "Android app" : "Aplicație Android",
     "iOS app" : "Aplicație iOS",
-    "Share link" : "Partajează link-ul",
     "Remove" : "Șterge",
-    "Enabled" : "Activat"
+    "Enabled" : "Activat",
+    "Share link" : "Partajează link-ul"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
