@@ -107,6 +107,7 @@ OC.L10N.register(
     "{actor} shared a file which is no longer available" : "{actor} delade en fil som inte längre är tillgänglig",
     "You shared a file which is no longer available" : "Du delade en fil som inte längre är tillgänglig",
     "%s (guest)" : "%s (gäst)",
+    "You missed a call from {user}" : "Du missade ett samtal från {user}",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Samtal med %n gäst (Varaktighet {duration})","Samtal med %n gäster (Varaktighet {duration})"],
     "Call with {user1} and {user2} (Duration {duration})" : "Samtal med {user1} och {user2} (Varade {duration})",
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Samtal med {user1}, {user2} och {user3} (Varade {duration})",
@@ -152,7 +153,6 @@ OC.L10N.register(
     "{user} invited you to a group conversation: {call}" : "{user} bjöd in dig till en gruppkonversation: {call}",
     "Answer call" : "Svara på samtal",
     "Call back" : "Ring tillbaka",
-    "You missed a call from {user}" : "Du missade ett samtal från {user}",
     "A group call has started in {call}" : "Ett gruppsamtal har startats i {call}",
     "You missed a group call in {call}" : "Du missade ett gruppsamtal i {call}",
     "{email} is requesting the password to access {file}" : "{email} begär lösenordet för åtkomst till {file}",
@@ -567,6 +567,7 @@ OC.L10N.register(
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Du väntar för närvarande i lobbyn. Detta möte är planerat till {startTime}",
     "Camera" : "Kamera",
     "Reply" : "Svara",
+    "Go to file" : "Gå till fil",
     "[Unknown username]" : "[Okänt användarnamn]",
     "Today" : "Idag",
     "Yesterday" : "Igår",
@@ -607,7 +608,6 @@ OC.L10N.register(
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk uppdaterades, du måste ladda om sidan innan du kan starta eller gå med i ett samtal.",
     "You will be able to join the call only after a moderator starts it." : "Du kommer att kunna gå med i samtalet först när en moderator startar det.",
     "Toggle fullscreen" : "Växla helskärm",
-    "Go to file" : "Gå till fil",
     "Rename conversation" : "Byt namn på konversation",
     "Grid view" : "Rutnätsvy",
     "Send" : "Skicka",
@@ -656,9 +656,11 @@ OC.L10N.register(
     "New in Talk 7" : "Nytt i Talk 7",
     "New in Talk 8" : "Nytt i Talk 8",
     "New in Talk 9" : "Nytt i Talk 9",
+    "New in Talk 10" : "Nytt i Talk 10",
+    "{actor} set up Matterbridge to synchronize this conversation with other chats." : "{actor} aktiverade Matterbridge för att synkronisera denna konversation med andra chattar",
+    "You set up Matterbridge to synchronize this conversation with other chats." : "Du aktiverade Matterbridge för att synkronisera denna konversation med andra chattar",
     "{user} wants to talk with you" : "{user} vill prata med dig",
     "Users that can not use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Användare som inte kan använda Talk längre kommer fortfarande att listas som deltagare i sina tidigare samtal och även deras chattmeddelanden kommer att behållas.",
-    "Signaling server URL" : "Signalerar serverwebbadress",
     "Error: Can not connect to server" : "Error: Kan inte ansluta till server",
     "UDP and TCP" : "UDP och TCP",
     "UDP only" : "endast UDP",
@@ -672,24 +674,16 @@ OC.L10N.register(
     "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Aktivera video (v) - Din anslutning får ett kort avbrott när du aktiverar videon för första gången",
     "This conversation is read only" : "Denna konversation är skrivskyddad",
     "Conversation, " : "Konversation, ",
-    "Default location for attachments" : "Standardplats för bilagor",
-    "Select default location for attachments" : "Välj standardplats för bilagor",
     "Allow guests to join via link " : "Tillåt gäster att ansluta via länk",
+    "Remove" : "Ta bort",
+    "Enabled" : "Aktiverad",
     "Participant settings" : "Deltagarinställningar",
     "Add participants to the conversation" : "Lägg till deltagare i konversationen",
-    "Projects" : "Projekt",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call" : "Nextcloud Talk uppdaterades, du måste ladda om sidan innan du kan starta eller gå med i ett samtal",
     "Share link" : "Dela länk",
     "Exit fullscreen (f)" : "Avsluta fullskärmsläge (f)",
     "Fullscreen (f)" : "Fullskärm (f)",
-    "Select a conversation to add to the project" : "Välj en konversation som ska läggas till i projektet",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Webbläsaren du använder stöds inte av Nextcloud Talk. Använd den senaste versionen av Mozilla Firefox, Microsoft Edge, Google Chrome eller Apple Safari.",
     "Error while uploading file" : "Fel vid uppladdning av fil",
-    "New in Talk 10" : "Nytt i Talk 10",
-    "{actor} set up Matterbridge to synchronize this conversation with other chats." : "{actor} aktiverade Matterbridge för att synkronisera denna konversation med andra chattar",
-    "You set up Matterbridge to synchronize this conversation with other chats." : "Du aktiverade Matterbridge för att synkronisera denna konversation med andra chattar",
-    "Remove" : "Ta bort",
-    "Enabled" : "Aktiverad",
     "{actor} set the description to \"%1$s\"" : "{actor} ändrade beskrivningen till \"%1$s\"",
     "You set the description to \"%1$s\"" : "Du ändrade beskrivningen till \"%1$s\"",
     "An administrator set the description to \"%1$s\"" : "En administratör ändrade beskrivningen till \"%1$s\""
