@@ -325,7 +325,7 @@ class Notifier {
 		}
 
 		try {
-			$participant = $room->getParticipant($userId);
+			$participant = $room->getParticipant($userId, false);
 			$notificationLevel = $participant->getAttendee()->getNotificationLevel();
 			if ($notificationLevel === Participant::NOTIFY_DEFAULT) {
 				if ($room->getType() === Room::ONE_TO_ONE_CALL) {
@@ -341,9 +341,11 @@ class Notifier {
 				// so they can see the room in their room list and
 				// the notification can be parsed and links to an existing room,
 				// where they are a participant of.
+				$user = $this->userManager->get($userId);
 				$this->participantService->addUsers($room, [[
 					'actorType' => Attendee::ACTOR_USERS,
 					'actorId' => $userId,
+					'displayName' => $user ? $user->getDisplayName() : $userId,
 				]]);
 				return true;
 			}
