@@ -24,7 +24,6 @@ declare(strict_types=1);
  */
 namespace OCA\Talk\Migration;
 
-use Doctrine\DBAL\Types\Type;
 use OCP\DB\ISchemaWrapper;
 use OCP\Migration\SimpleMigrationStep;
 use OCP\Migration\IOutput;
@@ -39,25 +38,30 @@ class Version3002Date20180319104030 extends SimpleMigrationStep {
 	 * @since 13.0.0
 	 */
 	public function changeSchema(IOutput $output, \Closure $schemaClosure, array $options): ?ISchemaWrapper {
-		/** @var ISchemaWrapper $schema */
-		$schema = $schemaClosure();
-
-		if (!$schema->hasTable('talk_guests')) {
-			$table = $schema->createTable('talk_guests');
-
-			$table->addColumn('session_hash', Type::STRING, [
-				'notnull' => false,
-				'length' => 64,
-			]);
-			$table->addColumn('display_name', Type::STRING, [
-				'notnull' => false,
-				'length' => 64,
-				'default' => '',
-			]);
-
-			$table->addUniqueIndex(['session_hash'], 'tg_session_hash');
-		}
-
-		return $schema;
+		/**
+		 * The table had to be redone so it contains a primary key
+		 * @see Version11000Date20201209142525
+		 *
+		 * $schema = $schemaClosure();
+		 *
+		 * if (!$schema->hasTable('talk_guests')) {
+		 * $table = $schema->createTable('talk_guests');
+		 *
+		 * $table->addColumn('session_hash', Type::STRING, [
+		 * 'notnull' => false,
+		 * 'length' => 64,
+		 * ]);
+		 * $table->addColumn('display_name', Type::STRING, [
+		 * 'notnull' => false,
+		 * 'length' => 64,
+		 * 'default' => '',
+		 * ]);
+		 *
+		 * $table->addUniqueIndex(['session_hash'], 'tg_session_hash');
+		 * }
+		 *
+		 * return $schema;
+		 */
+		return null;
 	}
 }
