@@ -97,6 +97,11 @@ trait TInitialState {
 			$this->talkConfig->getUserReadPrivacy($user->getUID())
 		);
 
+		$this->initialState->provideInitialState(
+			'play_sounds',
+			$this->serverConfig->getUserValue($user->getUID(), 'spreed', 'play_sounds', 'yes') === 'yes'
+		);
+
 		$attachmentFolder = $this->talkConfig->getAttachmentFolder($user->getUID());
 		$freeSpace = 0;
 
@@ -167,5 +172,10 @@ trait TInitialState {
 			'enable_matterbridge',
 			false
 		);
+
+		$this->initialState->provideInitialState(
+			'play_sounds',
+			false
+		);
 	}
 }
